Developer API reference
=======================

Interfaces
----------

.. automodule:: scrapyd.interfaces
   :members:
   :undoc-members:
   :special-members:

Config
------

.. automodule:: scrapyd.config
   :members:
   :undoc-members:

Exceptions
----------

.. automodule:: scrapyd.exceptions
   :members:
   :undoc-members:
